# -*- coding: utf-8 -*-
from setuphelpers import *

uninstallkey = []

# Defining variables
bin_name_string = "dopdf-%s.exe"
silent_args = "/SILENT /VERYSILENT /SUPPRESSMSGBOXES /NOCANCEL /NORESTART"  # /Languages="en-fr-es"
app_uninstallkey = ""  # Empty because uninstallkey change every versions
app_name = "doPDF"


def install():
    # Initializing variables
    package_version = control.version.split("-", 1)[0]
    major_version = package_version.split(".")[0]
    bin_name = bin_name_string % package_version
    is_already_installed = False

    # Installing the package
    for check_if_installed in installed_softwares(name=app_name):
        if check_if_installed["name"] == app_name:
            if check_if_installed["version"] == package_version:
                is_already_installed = True

    if not is_already_installed:
        print("Installing: %s" % bin_name)
        install_exe_if_needed(
            bin_name,
            silentflags=silent_args,
            key=app_uninstallkey,
            min_version=package_version,
        )
    else:
        print("INFO: %s is already installed in the correct version" % app_name)

    # Disabling Telemetry
    registry_setstring(
        HKEY_LOCAL_MACHINE,
        r"SOFTWARE\Softland\novaPDF %s\doPdf%s_Softland" % (major_version, major_version),
        "SendTelemetry",
        "False",
    )


def session_setup():
    print("Disabling: auto-update-check")

    # Initializing variables
    package_version = control.version.split("-", 1)[0]
    major_version = package_version.split(".")[0]

    registry_setstring(
        HKEY_CURRENT_USER,
        r"SOFTWARE\Softland\novaPDF %s\doPdf%s_Softland" % (major_version, major_version),
        "AutomaticUpdate",
        "0",
    )
    registry_delete(
        HKEY_CURRENT_USER,
        r"SOFTWARE\Softland\novaPDF %s\doPdf%s_Softland" % (major_version, major_version),
        "UpdateInterval",
    )


def uninstall():
    # Uninstalling the package
    for soft in installed_softwares(name=app_name):
        run_notfatal(WAPT.uninstall_cmd(soft["key"]))
    if len(installed_softwares("dopdf")) != 0:
        error("ERROR: %s is not fully uninstalled" % app_name)


def update_package():
    print("Download/Update package content from upstream binary sources")

    # Initializing variables
    proxies = get_proxies()
    version = "0.0.0"
    latest_bin = "dopdf-full.exe"
    url_dl = "https://download.dopdf.com/download/setup/dopdf-full.exe"

    print("Download url is: %s" % url_dl)

    # Downloading latest binaries
    if not isfile(latest_bin):
        print("Downloading: %s" % latest_bin)
        wget(url_dl, latest_bin, proxies=proxies)

        # Checking version from file
        version_from_file = get_version_from_binary(latest_bin)
        if version != version_from_file:
            os.rename(latest_bin, bin_name_string % version_from_file)
            version = version_from_file

        # Changing version of the package
        control.version = "%s-%s" % (version, int(control.version.split("-")[-1]) + 1)
        control.save_control_to_wapt()
        print("Changing package version to: %s in WAPT\\control" % control.version)

    # Deleting outdated binaries
    remove_outdated_binaries(latest_bin)


def get_proxies():
    import platform

    if platform.python_version_tuple()[0] == "3":
        from urllib.request import getproxies
    else:
        from urllib import getproxies
    return getproxies()


def get_version_from_binary(filename):
    if filename.endswith(".msi"):
        return get_msi_properties(filename)["ProductVersion"]
    else:
        return get_file_properties(filename)["ProductVersion"]


def remove_outdated_binaries(
    version,
    list_extensions=["exe", "msi", "deb", "rpm", "dmg", "pkg"],
    list_filename_contain=None,
):
    if type(list_extensions) != list:
        list_extensions = [list_extensions]
    if list_filename_contain:
        if type(list_filename_contain) != list:
            list_filename_contain = [list_filename_contain]
    list_extensions = ["." + ext for ext in list_extensions if ext[0] != "."]
    for file_ext in list_extensions:
        for bin_in_dir in glob.glob("*%s" % file_ext):
            if not version in bin_in_dir:
                remove_file(bin_in_dir)
            if list_filename_contain:
                for filename_contain in list_filename_contain:
                    if not filename_contain in bin_in_dir:
                        remove_file(bin_in_dir)
