# -*- coding: utf-8 -*-
from setuphelpers import *
import platform

uninstallkey = []

# Defining variables
bin_name = "SpotifyFullSetup.exe"
silent_args = "/silent"
app_dir = makepath(programfiles, "Spotify")
app_path = makepath(app_dir, bin_name)


def install():
    # Installing the package
    if not isdir(app_dir):
        mkdirs(app_dir)
    if isfile(app_path):
        remove_file(app_path)
    filecopyto(bin_name, app_dir)


def uninstall():
    # Uninstalling the package
    if isdir(app_dir):
        remove_tree(app_dir)


def session_setup():
    # Initializing variables
    package_version = control.version.split("-")[0]
    user_app_dir = makepath(user_local_appdata, "Discord", "app-%s" % package_version)
    split_user_reg_version = registry_readstring(
        HKEY_CURRENT_USER,
        r"SOFTWARE\Microsoft\Windows\CurrentVersion\Uninstall\Spotify",
        "DisplayVersion",
    ).split(".")
    user_reg_version = ".".join(split_user_reg_version[:4])

    # Installing the package in user environment
    if user_reg_version == "" or package_version > user_reg_version:
        print("Installing: %s in user environment" % (bin_name))
        install_exe_if_needed(app_path, silentflags=silent_args)


def update_package():
    print("Download/Update package content from upstream binary sources")

    # Getting proxy informations from WAPT settings
    proxy = {}
    if platform.system() == "Windows" and isfile(makepath(user_local_appdata(), "waptconsole", "waptconsole.ini")):
        proxywapt = inifile_readstring(
            makepath(user_local_appdata(), "waptconsole", "waptconsole.ini"),
            "global",
            "http_proxy",
        )
        if proxywapt:
            proxy = {"http": proxywapt, "https": proxywapt}

    # Initializing variables
    url_dl = "https://download.scdn.co/SpotifyFullSetup.exe"
    latest_bin = bin_name

    print("Download url is: %s" % url_dl)

    # Downloading latest binaries
    if isfile(bin_name):
        remove_file(bin_name)
    print("Downloading: %s" % latest_bin)
    wget(url_dl, bin_name, proxies=proxy)

    # Checking version from file
    split_version = get_file_properties(latest_bin)["ProductVersion"].split(".")
    version = ".".join(split_version[:4])

    # Changing version of the package
    control.version = "%s-%s" % (version, int(control.version.split("-")[-1]) + 1)
    control.save_control_to_wapt()
    print("Changing version to: %s in WAPT\\control" % control.version)
