def audit():
    # Declaring local variables
    audit_status = "OK"
    app_check = installed_softwares("Seafile")
    if app_check:
        installed_version = app_check[0]["version"]
        control.name = app_check[0]["name"]
    else:
        installed_version = ""
        control.name = control.package.split("-", 1)[-1].replace("-", " ").title()
    audit_version = False

    # Auditing software
    if not installed_version:
        print(f"{control.name} is not installed.")
        audit_status = "ERROR"
    elif audit_version and Version(installed_version, 4) < Version(control.get_software_version(), 4):
        print(f"{control.name} ({installed_version}) installed version should be: {control.get_software_version()}")
        audit_status = "WARNING"
    else:
        print(f"{control.name} is installed." if installed_version in control.name else f"{control.name} ({installed_version})  is installed.")
        audit_status = "OK"

    return audit_status


def audit():
    # Declaring local variables
    audit_status = "OK"
    hibernation_state = registry_readstring(HKEY_LOCAL_MACHINE, r"SYSTEM\CurrentControlSet\Control\Power", "HibernateEnabled")
    hiberfile_sys_file = makepath(systemdrive, "hiberfil.sys")

    # Auditing package
    if hibernation_state == "1":
        print("Hibernation is enabled.")
        audit_status = set_audit_status(audit_status, "ERROR")
    elif hibernation_state == "0":
        print("Hibernation is disabled.")
        # audit_status = set_audit_status(audit_status, "OK")
    if isfile(hiberfile_sys_file):
        print(f'"{hiberfile_sys_file}" exists. Please make sure that hibernation is disabled, the computer may need to be restarted.')
        audit_status = set_audit_status(audit_status, "WARNING")

    return audit_status


def set_audit_status(old_audit_status, new_audit_status):
    """Maintain higher criticality for audit status."""
    audit_level = {"OK": 0, "WARNING": 1, "ERROR": 2}

    old_status = old_audit_status.upper().strip()
    new_status = new_audit_status.upper().strip()

    if audit_level.get(new_status, -1) > audit_level.get(old_status, -1):
        return new_status
    else:
        return old_audit_status


def audit():
    # Declaring local variables
    audit_status = "OK"
    app_check = installed_softwares(name="^Google Chrome$")
    audit_version = True

    # Auditing software
    if not app_check:
        print("%s is not installed" % control.package.split("-", 1)[-1].replace("-", " ").title())
        audit_status = "ERROR"
    elif audit_version:
        for to_audit in app_check:
            if Version(to_audit["version"], 1) != Version(control.get_software_version(), 1):
                print(
                    f'{to_audit["name"]} version is: {to_audit["version"]} and {control.name} version is: {control.get_software_version()}\n{control.name} may not work.'
                )
                audit_status = "WARNING"

    return audit_status


def audit():
    # Declaring local variables
    audit_status = "OK"
    dotnet_version = control.get_software_version().split(".")[0]
    app_check = installed_softwares(name=f"Microsoft Windows Desktop Runtime - {dotnet_version}.*")
    audit_version = True

    # Auditing software
    if not app_check:
        print("%s is not installed" % control.package.split("-", 1)[-1].replace("-", " ").title())
        audit_status = "ERROR"
    elif audit_version:
        for to_audit in app_check:
            if "ProgramData\\Package Cache" in to_audit["uninstall_string"]:
                if Version(to_audit["version"]) < Version(control.get_software_version()):
                    print(f'{to_audit["name"]} is installed in version: {to_audit["version"]} instead of: {control.get_software_version()}.')
                    audit_status = "WARNING"
                else:
                    print("%s is installed and up-to-date." % to_audit["name"])

    return audit_status


def audit():
    # Declaring local variables
    app_check = installed_softwares(uninstallkey=app_uninstallkey)
    if app_check:
        installed_version = app_check[0]["version"]
        control.name = app_check[0]["name"]
    else:
        installed_version = None
        control.name = control.package.split("-", 1)[-1].replace("-", " ").title()

    # Auditing software
    if installed_version is None:
        print("%s is not installed" % control.name)
        return "ERROR"
    elif Version(installed_version, 4) < Version(control.get_software_version(), 4):
        print("%s is installed in version (%s) instead of (%s)" % (control.name, installed_version, control.get_software_version()))
        return "WARNING"
    else:
        print("%s (%s) is installed" % (control.name, installed_version))
        return "OK"
