def install():
    # Installing tis-waptpython-icoextract for Windows and Linux
    if not get_os_name() == "Darwin":
        dependency_package = control.package.split("-")[0] + "-waptpython-icoextract"
        if WAPT.is_available(dependency_package):
            WAPT.install(dependency_package)
        else:
            error(f"You must import the package: {dependency_package}")

    # Older Windows versions depends on PowerShell 5
    if windows_version() < WindowsVersions.Windows10:
        package_prefix = control.package.split("-", 1)[0]
        pkg_name = package_prefix + "-" + "powershell5"
        if not WAPT.is_installed(pkg_name):
            if WAPT.is_available(pkg_name):
                print("Installing: %s" % pkg_name)
                WAPT.install(pkg_name)
                WAPT.audit(pkg_name)
            else:
                error("ERROR: %s package not found on the repo, please import it" % pkg_name)


# -*- coding: utf-8 -*-
from setuphelpers import *

allow_arbitrary_install = True
package_depend_order_list_any_prefix = [
    "tis-selenium-chrome-driver",
    "tis-selenium-firefox-driver",
]


def install():
    unzip("selenium.zip")
    path_selenium = makepath(WAPT.wapt_base_dir, "selenium")
    mkdirs(path_selenium)
    copytree2("selenium", path_selenium)
    if get_os_name() == "Windows":
        add_to_system_path(path_selenium)

    # Meta package part
    package_prefix = control.package.split("-", 1)[0]
    package_depend_order_list = [package_prefix + "-" + x.split("-", 1)[1] for x in package_depend_order_list_any_prefix]
    package_depend_found = False

    if [y for y in package_depend_order_list if WAPT.is_installed(y)]:
        package_depend_found = True
        print("OK: A WAPT Selenium Driver is already installed with WAPT")
    else:
        if allow_arbitrary_install:
            print(
                "WARNING: A WAPT Selenium Driver will be installed with WAPT since this package allow arbitrary install based on available package in a specific order"
            )
            for pkg_name in package_depend_order_list:
                if WAPT.is_available(pkg_name):
                    package_depend_found = True
                    print("Installing: %s" % pkg_name)
                    WAPT.install(pkg_name)
                    WAPT.audit(pkg_name)
                    break
        if not package_depend_found:
            error(
                "ERROR: No WAPT Selenium Driver have been deployed on this system, please import and deploy the package adapted to your organization. Choose from\n%s"
                % package_depend_order_list_any_prefix
            )


def uninstall():
    path_selenium = makepath(WAPT.wapt_base_dir, "selenium")
    if isdir(path_selenium):
        remove_tree(path_selenium)
    if get_os_name() == "Windows":
        remove_from_system_path(path_selenium)
